/* ScrutariLib_DB - Copyright (c) 2010-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.scrutari.db.api;

import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.primitives.FuzzyDate;
import net.scrutari.data.BaseData;
import net.scrutari.data.CorpusData;
import net.scrutari.data.FicheData;
import net.scrutari.data.MotcleData;
import net.scrutari.data.ThesaurusData;
import net.scrutari.datauri.ScrutariDataURI;
import net.scrutari.datauri.ScrutariDataURIChecker;
import net.scrutari.db.api.codes.Codes;
import net.scrutari.db.api.codes.IndexationCodes;


/**
 *
 * @author Vincent Calame
 */
public interface DataAccess {

    public int getBaseCount();

    public int getCorpusCount();

    public int getThesaurusCount();

    public int getCode(ScrutariDataURI scrutariDataURI);

    public ScrutariDataURIChecker getScrutariDataURIChecker();

    /**
     * La nature de l'objet dépend de la classe de scrutariDataURI BaseURi =
     * BaseData, CorpusURI = CorpusData, ThesaurusURI = thesaurusData, FicheURI
     * = ficheData, MotcleURI = MotcleData
     */
    public Object getScrutariData(ScrutariDataURI scrutariDataURI);

    public BaseData getBaseDataByCode(int codebase);

    public BaseData getBaseDataByIndex(int index);

    public BaseData getBaseDataByScrutariSourceName(String scrutariSourceName);

    public CorpusData getCorpusDataByCode(int codecorpus);

    public CorpusData getCorpusDataByIndex(int index);

    public Codes getCorpusCodes();

    public ThesaurusData getThesaurusDataByCode(int codethesaurus);

    public ThesaurusData getThesaurusDataByIndex(int index);

    public Codes getThesaurusCodes();

    public MotcleData getMotcleDataByCode(int codemotcle);

    public FicheData getFicheDataByCode(int codefiche);

    public Lang getFicheLang(int codefiche);

    public FuzzyDate getFicheDate(int codefiche);

    public IndexationCodes getIndexationCodes(int elementCode, int subsetCode);

    public void close();

}
