/* ScrutariLib_Data - Copyright (c) 2005-2014 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.scrutari.data;

import java.io.IOException;
import java.io.Serializable;
import net.mapeadores.util.primitives.io.PrimitivesReader;
import net.mapeadores.util.primitives.io.PrimitivesWriter;


/**
 *
 * @author Vincent Calame
 */
public final class IndexationData implements Serializable {

    private final int codecorpus;
    private final int codethesaurus;
    private final int codemotcle;
    private final int codefiche;
    private final int poids;

    public IndexationData(int codefiche, int codecorpus, int codemotcle, int codethesaurus, int poids) {
        this.codecorpus = codecorpus;
        this.codefiche = codefiche;
        this.codethesaurus = codethesaurus;
        this.codemotcle = codemotcle;
        this.poids = poids;
    }

    public int getCodeMotcle() {
        return codemotcle;
    }

    public int getCodeThesaurus() {
        return codethesaurus;
    }

    public int getCodeFiche() {
        return codefiche;
    }

    public int getCodeCorpus() {
        return codecorpus;
    }

    public int getPoids() {
        return poids;
    }

    public static IndexationData fromPrimitives(PrimitivesReader primitivesReader) throws IOException {
        int codefiche = primitivesReader.readInt();
        int codemotcle = primitivesReader.readInt();
        int codecorpus = primitivesReader.readInt();
        int codethesaurus = primitivesReader.readInt();
        int poids = primitivesReader.readInt();
        return new IndexationData(codefiche, codecorpus, codemotcle, codethesaurus, poids);
    }

    public static void toPrimitives(IndexationData indexationData, PrimitivesWriter primitivesWriter) throws IOException {
        primitivesWriter.writeInt(indexationData.codefiche);
        primitivesWriter.writeInt(indexationData.codemotcle);
        primitivesWriter.writeInt(indexationData.codecorpus);
        primitivesWriter.writeInt(indexationData.codethesaurus);
        primitivesWriter.writeFloat(indexationData.poids);
    }

}
