/* ScrutariLib_SearchEngine - Copyright (c) 2010-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.scrutari.searchengine.tools.result;

import java.util.AbstractList;
import java.util.Collections;
import java.util.List;
import java.util.RandomAccess;
import net.mapeadores.util.localisation.Lang;
import net.scrutari.searchengine.api.result.FicheSearchResultGroup;
import net.scrutari.searchengine.api.result.FicheSearchResultInfo;
import net.scrutari.searchengine.api.result.InAlineaOccurrences;
import net.scrutari.searchengine.api.result.InLangOccurrences;
import net.scrutari.searchengine.api.result.MotcleSearchResultInfo;
import net.scrutari.searchengine.api.result.SearchTokenOccurrence;
import net.scrutari.searchengine.api.result.SupermotcleSearchResult;
import net.scrutari.searchengine.api.result.SupermotcleSearchResultInfo;


/**
 *
 * @author Vincent Calame
 */
public final class ResultUtils {

    public final static List<SearchTokenOccurrence> EMPTY_SEARCHTOKENOCCURRENCELIST = Collections.emptyList();
    public final static List<InAlineaOccurrences> EMPTY_INALINEAOCCURRENCESLIST = Collections.emptyList();
    public final static List<InLangOccurrences> EMPTY_INLANGOCCURRENCESLIST = Collections.emptyList();
    public final static List<SupermotcleSearchResultInfo> EMPTY_SUPERMOTCLESEARCHRESULTINFOLIST = Collections.emptyList();
    public final static SupermotcleSearchResult EMPTY_SUPERMOTCLE_SEARCHRESULT = new EmptySupermotcleSearchResult();

    private ResultUtils() {
    }

    public static InAlineaOccurrences toInAlineaOccurrences(int alineaInteger, SearchTokenOccurrence[] array) {
        return new InternalInAlineaOccurrences(alineaInteger, array);
    }

    public static InLangOccurrences toInLangOccurrences(Lang lang, SearchTokenOccurrence[] array) {
        return new InternalInLangOccurrences(lang, array);
    }

    public static List<SearchTokenOccurrence> wrap(SearchTokenOccurrence[] array) {
        return new SearchTokenOccurrenceList(array);
    }

    public static int compare(List<SearchTokenOccurrence> list1, List<SearchTokenOccurrence> list2) {
        int size1 = list1.size();
        int size2 = list2.size();
        if (size1 > size2) {
            return 1;
        }
        if (size1 < size2) {
            return -1;
        }
        int diff = 0;
        for (int i = 0; i < size1; i++) {
            SearchTokenOccurrence tokenOccurrence1 = list1.get(i);
            SearchTokenOccurrence tokenOccurrence2 = list2.get(i);
            int tk1 = tokenOccurrence1.getOperandNumber();
            int tk2 = tokenOccurrence2.getOperandNumber();
            if (tk1 < tk2) {
                return 1;
            }
            if (tk1 > tk1) {
                return -1;
            }
            int start1 = tokenOccurrence1.getBeginIndex();
            int start2 = tokenOccurrence2.getBeginIndex();
            if (start1 < start2) {
                return 1;
            }
            if (start1 > start2) {
                return -1;
            }
            if (diff == 0) {
                int ln1 = tokenOccurrence1.getLength();
                int ln2 = tokenOccurrence2.getLength();
                if (ln1 < ln2) {
                    diff = 1;
                }
                if (ln1 > ln2) {
                    diff = -1;
                }
            }
        }
        if (diff != 0) {
            return diff;
        }
        return 0;
    }

    public static List<InAlineaOccurrences> wrap(InAlineaOccurrences[] array) {
        return new InAlineaOccurrencesList(array);
    }

    public static List<InLangOccurrences> wrap(InLangOccurrences[] array) {
        return new InLangOccurrencesList(array);
    }

    public static List<SupermotcleSearchResultInfo> wrap(SupermotcleSearchResultInfo[] array) {
        return new SupermotcleSearchResultInfoList(array);
    }

    public static List<MotcleSearchResultInfo> wrap(MotcleSearchResultInfo[] array) {
        return new MotcleSearchResultInfoList(array);
    }

    public static List<FicheSearchResultGroup> wrap(FicheSearchResultGroup[] array) {
        return new FicheSearchResultGroupList(array);
    }

    public static List<FicheSearchResultInfo> wrap(FicheSearchResultInfo[] array) {
        return new FicheSearchResultInfoList(array);
    }


    private static class EmptySupermotcleSearchResult implements SupermotcleSearchResult {

        private EmptySupermotcleSearchResult() {

        }

        @Override
        public List<SupermotcleSearchResultInfo> getSupermotcleSearchResultInfoList() {
            return EMPTY_SUPERMOTCLESEARCHRESULTINFOLIST;
        }

    }


    private static class InternalInAlineaOccurrences implements InAlineaOccurrences {

        private final int alineaInteger;
        private final List<SearchTokenOccurrence> list;

        private InternalInAlineaOccurrences(int alineaInteger, SearchTokenOccurrence[] array) {
            this.alineaInteger = alineaInteger;
            this.list = wrap(array);
        }

        @Override
        public int getAlineaInteger() {
            return alineaInteger;
        }

        @Override
        public List<SearchTokenOccurrence> getSearchTokenOccurrenceList() {
            return list;
        }

    }


    private static class InternalInLangOccurrences implements InLangOccurrences {

        private final Lang lang;
        private final List<SearchTokenOccurrence> list;

        private InternalInLangOccurrences(Lang lang, SearchTokenOccurrence[] array) {
            this.lang = lang;
            this.list = wrap(array);
        }

        @Override
        public Lang getLang() {
            return lang;
        }

        @Override
        public List<SearchTokenOccurrence> getSearchTokenOccurrenceList() {
            return list;
        }

    }


    private static class SearchTokenOccurrenceList extends AbstractList<SearchTokenOccurrence> implements RandomAccess {

        private final SearchTokenOccurrence[] array;

        private SearchTokenOccurrenceList(SearchTokenOccurrence[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public SearchTokenOccurrence get(int index) {
            return array[index];
        }

    }


    private static class InAlineaOccurrencesList extends AbstractList<InAlineaOccurrences> implements RandomAccess {

        private final InAlineaOccurrences[] array;

        private InAlineaOccurrencesList(InAlineaOccurrences[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public InAlineaOccurrences get(int index) {
            return array[index];
        }

    }


    private static class InLangOccurrencesList extends AbstractList<InLangOccurrences> implements RandomAccess {

        private final InLangOccurrences[] array;

        private InLangOccurrencesList(InLangOccurrences[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public InLangOccurrences get(int index) {
            return array[index];
        }

    }


    private static class SupermotcleSearchResultInfoList extends AbstractList<SupermotcleSearchResultInfo> implements RandomAccess {

        private final SupermotcleSearchResultInfo[] array;

        private SupermotcleSearchResultInfoList(SupermotcleSearchResultInfo[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public SupermotcleSearchResultInfo get(int index) {
            return array[index];
        }

    }


    private static class MotcleSearchResultInfoList extends AbstractList<MotcleSearchResultInfo> implements RandomAccess {

        private final MotcleSearchResultInfo[] array;

        private MotcleSearchResultInfoList(MotcleSearchResultInfo[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public MotcleSearchResultInfo get(int index) {
            return array[index];
        }

    }


    private static class FicheSearchResultGroupList extends AbstractList<FicheSearchResultGroup> implements RandomAccess {

        private final FicheSearchResultGroup[] array;

        private FicheSearchResultGroupList(FicheSearchResultGroup[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public FicheSearchResultGroup get(int index) {
            return array[index];
        }

    }


    private static class FicheSearchResultInfoList extends AbstractList<FicheSearchResultInfo> implements RandomAccess {

        private final FicheSearchResultInfo[] array;

        private FicheSearchResultInfoList(FicheSearchResultInfo[] array) {
            this.array = array;
        }

        @Override
        public int size() {
            return array.length;
        }

        @Override
        public FicheSearchResultInfo get(int index) {
            return array[index];
        }

    }


}
