/* SctServer - Copyright (c) 2015-2016 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.sctserver.json;

import java.io.IOException;
import net.mapeadores.util.json.JSONWriter;
import net.mapeadores.util.localisation.Lang;
import net.scrutari.data.CorpusData;
import net.scrutari.datauri.CorpusURI;
import net.scrutari.db.api.stats.ScrutariDBStats;
import net.scrutari.db.tools.util.DataLabelUtils;


/**
 *
 * @author Vincent Calame
 */
public final class CorpusDataJson {

    private CorpusDataJson() {

    }

    public static void object(JSONWriter jsonWriter, CorpusData corpusData, Lang langUi, ScrutariDBStats scrutariDBStats) throws IOException {
        int code = corpusData.getCodeCorpus();
        jsonWriter.object();
        jsonWriter.key("codecorpus");
        jsonWriter.value(code);
        jsonWriter.key("codebase");
        jsonWriter.value(corpusData.getCodeBase());
        CorpusURI corpusURI = corpusData.getCorpusURI();
        String corpusName = corpusURI.getCorpusName();
        jsonWriter.key("corpusname");
        jsonWriter.value(corpusName);
        int complementCount = corpusData.getComplementMaxNumber();
        jsonWriter.key("complementCount");
        jsonWriter.value(complementCount);
        jsonWriter.key("intitules");
        jsonWriter.object();
        jsonWriter.key("corpus");
        jsonWriter.value(DataLabelUtils.checkLabelString(corpusData, CorpusData.INTITULECORPUS_FIELDNUMBER, langUi, corpusName));
        jsonWriter.key("fiche");
        jsonWriter.value(DataLabelUtils.checkLabelString(corpusData, CorpusData.INTITULEFICHE_FIELDNUMBER, langUi, corpusName));
        for (int j = 1; j <= complementCount; j++) {
            jsonWriter.key("complement_" + j);
            jsonWriter.value(DataLabelUtils.checkLabelString(corpusData, j, langUi, "complement_" + j));
        }
        jsonWriter.endObject();
        if (scrutariDBStats != null) {
            jsonWriter.key("stats");
            jsonWriter.object();
            JsonUtils.addCountStats(jsonWriter, scrutariDBStats.getCountStats(code));
            JsonUtils.addFicheStats(jsonWriter, scrutariDBStats.getFicheStats(code));
            jsonWriter.endObject();
        }
        jsonWriter.endObject();
    }

}
