/* SctServer - Copyright (c) 2011-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.sctserver.request.json;

import java.io.IOException;
import java.util.List;
import net.mapeadores.util.json.JSONWriter;
import net.mapeadores.util.localisation.Message;
import net.mapeadores.util.localisation.MessageLocalisation;
import net.mapeadores.util.logging.CommandMessage;


/**
 *
 * @author Vincent Calame
 */
public class ErrorJsonProducer extends AbstractJsonProducer {

    private final CommandMessage commandMessage;
    private final MessageLocalisation messageLocalisation;

    public ErrorJsonProducer(CommandMessage commandMessage, MessageLocalisation messageLocalisation) {
        this.commandMessage = commandMessage;
        this.messageLocalisation = messageLocalisation;
    }

    @Override
    public void writeJson(Appendable appendable) throws IOException {
        String errorKey = commandMessage.getMessageKey();
        Object[] values = commandMessage.getMessageValues();
        String parameter;
        String value = null;
        int length = values.length;
        if (length == 0) {
            parameter = "";
        } else {
            parameter = values[0].toString();
            if (length > 1) {
                value = values[1].toString();
            }
        }
        JSONWriter jsonWriter = new JSONWriter(appendable);
        jsonWriter.object();
        jsonWriter.key("error");
        jsonWriter.object();
        jsonWriter.key("key");
        jsonWriter.value(errorKey);
        jsonWriter.key("parameter");
        jsonWriter.value(parameter);
        if (value != null) {
            jsonWriter.key("value");
            jsonWriter.value(value);
        }
        if (messageLocalisation != null) {
            jsonWriter.key("text");
            jsonWriter.value(messageLocalisation.toString(commandMessage));
        }
        if (commandMessage.hasMultiError()) {
            addErrorList(jsonWriter, commandMessage.getMultiErrorList(), messageLocalisation);
        }
        jsonWriter.endObject();
        writeWarnings(jsonWriter);
        jsonWriter.endObject();
    }

    private static void addErrorList(JSONWriter jsonWriter, List<Message> errorList, MessageLocalisation messageLocalisation) throws IOException {
        jsonWriter.key("array");
        jsonWriter.array();
        for (Message errorMessage : errorList) {
            jsonWriter.object();
            jsonWriter.key("key");
            jsonWriter.value(errorMessage.getMessageKey());
            Object[] values = errorMessage.getMessageValues();
            if (values.length > 0) {
                jsonWriter.key("value");
                jsonWriter.value(values[0].toString());
            }
            if (messageLocalisation != null) {
                jsonWriter.key("text");
                jsonWriter.value(messageLocalisation.toString(errorMessage));
            }
            jsonWriter.endObject();
        }
        jsonWriter.endArray();
    }

}
