/* SctEngine - Copyright (c) 2013 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.sctserver.tools.log;

import fr.exemole.sctserver.api.ScrutariSession;
import fr.exemole.sctserver.api.log.QLog;
import fr.exemole.sctserver.api.log.SctLogConstants;
import net.scrutari.searchengine.api.result.FicheSearchResult;


/**
 *
 * @author Vincent Calame
 */
public final class SctLogUtils {

    private SctLogUtils() {
    }

    public static void log(ScrutariSession scrutariSession, FicheSearchResult ficheSearchResult, String origin) {
        QLog qLog = new InternalQLog(ficheSearchResult.getFicheSearchSource().getCanonicalQ().toString(), origin, ficheSearchResult.getFicheCount(), ficheSearchResult.getFicheMaximum());
        scrutariSession.getEngine().getEngineStorage().getLogStorage().log(scrutariSession, qLog);
    }

    public static short logTypeToShort(String logTypeString) {
        if (logTypeString.equals("conf")) {
            return SctLogConstants.CONF_LOG;
        }
        if (logTypeString.equals("update")) {
            return SctLogConstants.UPDATE_LOG;
        }
        throw new IllegalArgumentException("Unknown logType: " + logTypeString);
    }

    public static String logTypeToString(short logType) {
        switch (logType) {
            case SctLogConstants.CONF_LOG:
                return "conf";
            case SctLogConstants.UPDATE_LOG:
                return "update";
            case SctLogConstants.START_LOG:
                return "start";
            default:
                throw new IllegalArgumentException("Unknown logType: " + logType);
        }
    }


    private static class InternalQLog implements QLog {

        private final String q;
        private final String origin;
        private final int ficheCount;
        private final int ficheMaximum;

        private InternalQLog(String q, String origin, int ficheCount, int ficheMaximum) {
            this.q = q;
            this.origin = origin;
            this.ficheCount = ficheCount;
            this.ficheMaximum = ficheMaximum;
        }

        @Override
        public String getQ() {
            return q;
        }

        @Override
        public String getOrigin() {
            return origin;
        }

        @Override
        public int getFicheCount() {
            return ficheCount;
        }

        @Override
        public int getFicheMaximum() {
            return ficheMaximum;
        }

    }

}
